<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Account\IAccountService;

class AccountController extends BaseController
{
    private $time;
    private $accountService;

    public function __construct(IAccountService $accountService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->accountService = $accountService;
    }

    /**
     * 平台列表
     * @return array
     * @date 2021/07/30
     * @author live
     */
    public function getPlatformList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->accountService->getPlatformList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 渠道列表
     * @return array
     * @date 2021/07/30
     * @author live
     */
    public function getChannelList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->accountService->getChannelList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 货币类型列表
     * @return array
     * @date 2021/07/30
     * @author live
     */
    public function getCurrencyList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->accountService->getCurrencyList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 货币列表
     * @return array
     * @date 2021/07/30
     * @author live
     */
    public function getAccountLog(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->accountService->getAccountLog($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }



}