<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\User\IUserService;

class UserController extends BaseController
{
    private $time;
    private $userService;

    public function __construct(IUserService $userService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->userService = $userService;
    }

    /**
     * 新增用户
     * @return array
     * @date 2021/07/29
     * @author live
     */
    public function getUserAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'name' => 'required|string',
            'realName' => 'required|string',
            'pwd' => 'required|string'
        ]);
        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->userService->getUserAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 用户列表
     * @return array
     * @date 2021/07/29
     * @author live
     */
    public function getUserList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->userService->getUserList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }




    /**
     * 删除用户
     * @return array
     * @date 2021/07/29
     * @author live
     */
    public function getUserDel(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric'
        ]);

        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->userService->getUserDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }



    /**
     * 修改用户登录密码
     * @return array
     * @date 2021/07/29
     * @author live
     */
    public function getResetUserPwd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'pwd' => 'required|string|min:6'
        ]);
        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->userService->getResetUserPwd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 设置用户状态
     * @return array
     * @date 2021/07/29
     * @author live
     */
    public function getSetStatus(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'status' => 'required|numeric'
        ]);
        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->userService->getSetStatus($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }


}